timerelationtools.offset_happens_after_timespan_starts
======================================================

.. autofunction:: abjad.tools.timerelationtools.offset_happens_after_timespan_starts.offset_happens_after_timespan_starts
   :noindex:
